/*
 * Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */

#ifndef __HANDLER_APPUI_H__
#define __HANDLER_APPUI_H__

#include <aknappui.h>
#include <DocumentHandler.h>

// Forward reference
class CHandlerAppView;

/*! 
  @class CHandlerAppUi
  
  @discussion An instance of class CHandlerAppUi is the UserInterface part of the AVKON
  application framework for the handler example application
  */
class CHandlerAppUi : public CAknAppUi                                 
    {
    public:
    /*!
      @function ConstructL
      
      @discussion Perform the second phase construction of a CHandlerAppUi object
      this needs to be public due to the way the framework constructs the AppUi 
      */
        void ConstructL();

    /*!
      @function CHandlerAppUi
      
      @discussion Perform the first phase of two phase construction.
      This needs to be public due to the way the framework constructs the AppUi 
      */
        CHandlerAppUi();

    /*!
      @function ~CHandlerAppUi
      
      @discussion Destroy the object and release all memory objects
      */
        ~CHandlerAppUi();

        void SetFileData(TFileName& aFileName, TDes8& aData);

    public: // from CAknAppUi

        /**
        * From CAknAppUi, handles file change.
        * @param aFileName New file to be opened.
        */
    	void OpenFileL( const TDesC& aFileName );  

        /*!
        * See CAknAppUi
        */
        void HandleCommandL(TInt aCommand);
        
        /*!
        * See CAknAppUi
        */
        void HandleResourceChangeL(TInt aType);

        /*!
        * See CAknAppUi
        */
        TBool ProcessCommandParametersL(TApaCommand aCommand,TFileName& aDocumentName);

        /*!
        * See CAknAppUi
        */
        TBool ProcessCommandParametersL(TApaCommand aCommand,TFileName& aDocumentName,const TDesC8& aTail);
        
    private:
        
        /**!
        * Returns true if the application is embedded
        */
        TBool IsEmbedded();
        
    private:

        // The application view
        CHandlerAppView* iAppView;

    };


#endif // __HANDLER_APPUI_H__

